@@ -4,14 +4,14 @@
 
     Forms used in the cart
 
-    :copyright: (c) 2010-2012 by Openlabs Technologies & Consulting (P) LTD
+    :copyright: (c) 2010-2014 by Openlabs Technologies & Consulting (P) LTD
     :license: GPLv3, see LICENSE for more details
-    '''
-from wtforms import Form, validators
-from wtforms import IntegerField, FloatField
-
-from .i18n import _
+'''
+from flask_wtf import Form
+from wtforms import validators, IntegerField, FloatField
+from nereid.contrib.locale import make_lazy_gettext
 
+_ = make_lazy_gettext('nereid_cart_b2c')
 _VDTR = [validators.Required(message=_("This field is required"))]
 
 
